Stan Math Library: stan::math::LDLT_factor< T, R, C > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::LDLT_factor< T, R, C > Class Template Reference

`#include <LDLT_factor.hpp>`

## Detailed Description

### template<typename T, int R, int C>
class stan::math::LDLT_factor< T, R, C >

Definition at line 18 of file LDLT_factor.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/mat/fun/LDLT_factor.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.